@@ -1,7 +1,7 @@
 """
 Type annotations for compute-optimizer service client.
 
-[Open documentation](./client.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html)
 
 Usage::
 
@@ -79,8 +79,8 @@ class Exceptions:
 
 class ComputeOptimizerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
-    [Show boto3-stubs documentation](./client.md)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html)
     """
 
     meta: ClientMeta
@@ -88,76 +88,81 @@ class ComputeOptimizerClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#can_paginate)
         """
 
     def describe_recommendation_export_jobs(
         self,
+        *,
         jobIds: List[str] = None,
         filters: List[JobFilterTypeDef] = None,
         nextToken: str = None,
-        maxResults: int = None,
+        maxResults: int = None
     ) -> DescribeRecommendationExportJobsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
-        [Show boto3-stubs documentation](./client.md#describe_recommendation_export_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#describe_recommendation_export_jobs)
         """
 
     def export_auto_scaling_group_recommendations(
         self,
+        *,
         s3DestinationConfig: S3DestinationConfigTypeDef,
         accountIds: List[str] = None,
         filters: List[FilterTypeDef] = None,
         fieldsToExport: List[ExportableAutoScalingGroupFieldType] = None,
         fileFormat: Literal["Csv"] = None,
-        includeMemberAccounts: bool = None,
+        includeMemberAccounts: bool = None
     ) -> ExportAutoScalingGroupRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
-        [Show boto3-stubs documentation](./client.md#export_auto_scaling_group_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_auto_scaling_group_recommendations)
         """
 
     def export_ebs_volume_recommendations(
         self,
+        *,
         s3DestinationConfig: S3DestinationConfigTypeDef,
         accountIds: List[str] = None,
         filters: List[EBSFilterTypeDef] = None,
         fieldsToExport: List[ExportableVolumeFieldType] = None,
         fileFormat: Literal["Csv"] = None,
-        includeMemberAccounts: bool = None,
+        includeMemberAccounts: bool = None
     ) -> ExportEBSVolumeRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ebs_volume_recommendations)
-        [Show boto3-stubs documentation](./client.md#export_ebs_volume_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ebs_volume_recommendations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_ebs_volume_recommendations)
         """
 
     def export_ec2_instance_recommendations(
         self,
+        *,
         s3DestinationConfig: S3DestinationConfigTypeDef,
         accountIds: List[str] = None,
         filters: List[FilterTypeDef] = None,
         fieldsToExport: List[ExportableInstanceFieldType] = None,
         fileFormat: Literal["Csv"] = None,
-        includeMemberAccounts: bool = None,
+        includeMemberAccounts: bool = None
     ) -> ExportEC2InstanceRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
-        [Show boto3-stubs documentation](./client.md#export_ec2_instance_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_ec2_instance_recommendations)
         """
 
     def export_lambda_function_recommendations(
         self,
+        *,
         s3DestinationConfig: S3DestinationConfigTypeDef,
         accountIds: List[str] = None,
         filters: List[LambdaFunctionRecommendationFilterTypeDef] = None,
         fieldsToExport: List[ExportableLambdaFunctionFieldType] = None,
         fileFormat: Literal["Csv"] = None,
-        includeMemberAccounts: bool = None,
+        includeMemberAccounts: bool = None
     ) -> ExportLambdaFunctionRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_lambda_function_recommendations)
-        [Show boto3-stubs documentation](./client.md#export_lambda_function_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_lambda_function_recommendations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_lambda_function_recommendations)
         """
 
     def generate_presigned_url(
@@ -168,93 +173,98 @@ class ComputeOptimizerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#generate_presigned_url)
         """
 
     def get_auto_scaling_group_recommendations(
         self,
+        *,
         accountIds: List[str] = None,
         autoScalingGroupArns: List[str] = None,
         nextToken: str = None,
         maxResults: int = None,
-        filters: List[FilterTypeDef] = None,
+        filters: List[FilterTypeDef] = None
     ) -> GetAutoScalingGroupRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
-        [Show boto3-stubs documentation](./client.md#get_auto_scaling_group_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_auto_scaling_group_recommendations)
         """
 
     def get_ebs_volume_recommendations(
         self,
+        *,
         volumeArns: List[str] = None,
         nextToken: str = None,
         maxResults: int = None,
         filters: List[EBSFilterTypeDef] = None,
-        accountIds: List[str] = None,
+        accountIds: List[str] = None
     ) -> GetEBSVolumeRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ebs_volume_recommendations)
-        [Show boto3-stubs documentation](./client.md#get_ebs_volume_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ebs_volume_recommendations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ebs_volume_recommendations)
         """
 
     def get_ec2_instance_recommendations(
         self,
+        *,
         instanceArns: List[str] = None,
         nextToken: str = None,
         maxResults: int = None,
         filters: List[FilterTypeDef] = None,
-        accountIds: List[str] = None,
+        accountIds: List[str] = None
     ) -> GetEC2InstanceRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
-        [Show boto3-stubs documentation](./client.md#get_ec2_instance_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ec2_instance_recommendations)
         """
 
     def get_ec2_recommendation_projected_metrics(
         self,
+        *,
         instanceArn: str,
         stat: MetricStatisticType,
         period: int,
         startTime: datetime,
-        endTime: datetime,
+        endTime: datetime
     ) -> GetEC2RecommendationProjectedMetricsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
-        [Show boto3-stubs documentation](./client.md#get_ec2_recommendation_projected_metrics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ec2_recommendation_projected_metrics)
         """
 
     def get_enrollment_status(self) -> GetEnrollmentStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
-        [Show boto3-stubs documentation](./client.md#get_enrollment_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_enrollment_status)
         """
 
     def get_lambda_function_recommendations(
         self,
+        *,
         functionArns: List[str] = None,
         accountIds: List[str] = None,
         filters: List[LambdaFunctionRecommendationFilterTypeDef] = None,
         nextToken: str = None,
-        maxResults: int = None,
+        maxResults: int = None
     ) -> GetLambdaFunctionRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_lambda_function_recommendations)
-        [Show boto3-stubs documentation](./client.md#get_lambda_function_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_lambda_function_recommendations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_lambda_function_recommendations)
         """
 
     def get_recommendation_summaries(
-        self, accountIds: List[str] = None, nextToken: str = None, maxResults: int = None
+        self, *, accountIds: List[str] = None, nextToken: str = None, maxResults: int = None
     ) -> GetRecommendationSummariesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
-        [Show boto3-stubs documentation](./client.md#get_recommendation_summaries)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_recommendation_summaries)
         """
 
     def update_enrollment_status(
         self, status: StatusType, includeMemberAccounts: bool = None
     ) -> UpdateEnrollmentStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
-        [Show boto3-stubs documentation](./client.md#update_enrollment_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#update_enrollment_status)
         """
